<?php
$lang['expired_searchable'] = 'Articulos expirados pueden aparecer en resultados de busquedas';
$lang['helpshowall'] = 'Mostrar todos los articulos, sin importar la fecha en que finalizan';
$lang['error_invaliddates'] = 'Una o mas de las fechas ingresadas son invalidas';
$lang['notify_n_draft_items_sub'] = 'Articulo(s) de noticias s%';
$lang['notify_n_draft_items'] = 'Tienes <a href="moduleinterface.php?module=News">%d art&iacute;culos de noticias</a> que no han sido publicados';
$lang['unlimited'] = 'Ilimitado';
$lang['none'] = 'Ninguno';
$lang['anonymous'] = 'An&oacute;nimo';
$lang['unknown'] = 'Desconocido';
$lang['fesubmit_redirect'] = 'El ID o Alias de la pagina a redireccionar despues de que un articulo de noticias ha sido enviado a trav&eacute;s de la acci&oacute;n FEsubmit.';
$lang['allow_summary_wysiwyg'] = 'Permitir uso de Editor WYSIWYG en el campo del sumario';
$lang['title_browsecat_template'] = 'Editor de Plantillas de Categor&iacute;as para Explorar';
$lang['title_browsecat_sysdefault'] = 'Plantilla por Defecto para Explorar Categor&iacute;as';
$lang['browsecattemplate'] = 'Plantillas de Categor&iacute;as para Explorar';
$lang['error_filesize'] = 'Se ha subido un archivo que excede el tama&ntilde;o m&aacute;ximo permitido';
$lang['post_date_desc'] = 'Fecha Entrada Descendente';
$lang['post_date_asc'] = 'Fecha Entrada Ascendente';
$lang['expiry_date_desc'] = 'Fecha Vence Descendente';
$lang['expiry_date_asc'] = 'Fecha Vence Ascendente';
$lang['title_desc'] = 'T&iacute;tulo Descendente';
$lang['title_asc'] = 'T&iacute;tulo Ascendente';
$lang['fesubmit_status'] = 'El estado de art&iacute;culos de noticias enviados v&iacute;a el portal';
$lang['error_invalidfiletype'] = 'No se puede subir este tipo de archivo';
$lang['error_upload'] = 'Ha ocurrido un problema subiendo un archivo';
$lang['error_movefile'] = 'No se pudo crear el archivo: %s';
$lang['error_mkdir'] = 'No se pudo crear el directorio: %s';
$lang['expiry_interval'] = 'El n&uacute;mero de d&iacute;as (por defecto) antes que un art&iacute;culo haya vencido (si se elige vencer)';
$lang['removed'] = 'Quitado';
$lang['msg_contenttype_removed'] = 'El tipo de contenido de noticias se ha quitado.  Por favor ubique los tags {news} con los par&aacute;metros apropiados en su plantilla de p&aacute;gina o en su contenido de p&aacute;gina para reemplazar &eacute;sta funcionalidad.';
$lang['delete_selected'] = 'Eliminar los Art&iacute;culos Elegidos';
$lang['areyousure_deletemultiple'] = '&iquest;Est&aacute; seguro que quiere eliminar a todos estos art&iacute;culos de noticias?\n&iexcl;Esta acci&oacute;n es irrecuperable!';
$lang['error_templatenamexists'] = 'Una plantilla con ese nombre ya existe';
$lang['error_noarticlesselected'] = 'No se Han Elegido Art&iacute;culos';
$lang['reassign_category'] = 'Cambiar Categor&iacute;a A';
$lang['select'] = 'Seleccionar';
$lang['approve'] = 'Poner Estado a &#039;Publicado&#039;';
$lang['revert'] = 'Poner Estado a &#039;Borrador&#039;';
$lang['hide_summary_field'] = 'Esconder el campo resumen cuando se agrega o editan art&iacute;culos';
$lang['textbox'] = 'Ingreso de Texto';
$lang['checkbox'] = 'Caja de Tilde';
$lang['textarea'] = '&Aacute;rea de Texto';
$lang['file'] = 'Archivo';
$lang['auto_create_thumbnails'] = 'Autom&aacute;ticamente crear archivos de miniaturas para archivos con &eacute;stas extensiones';
$lang['allowed_upload_types'] = 'Permitir que se suban s&oacute;lo archivos con &eacute;stas extensiones';
$lang['fielddefupdated'] = 'Definici&oacute;n de Campo Actualizada';
$lang['editfielddef'] = 'Editar Definici&oacute;n de Campo';
$lang['up'] = 'Arriba';
$lang['down'] = 'Abajo';
$lang['fielddefdeleted'] = 'Definici&oacute;n de Campo Eliminada';
$lang['nameexists'] = 'Un campo con ese nombre ya existe';
$lang['notanumber'] = 'La Longitud M&aacute;xima No es un N&uacute;mero';
$lang['fielddef'] = 'Definici&oacute;n de Campo';
$lang['fielddefadded'] = 'Definici&oacute;n de Campo Agregada con &Eacute;xito';
$lang['public'] = 'P&uacute;blico';
$lang['type'] = 'Tipo';
$lang['info_maxlength'] = 'La longitud m&aacute;xima se aplica s&oacute;lo a campos de ingreso de texto.';
$lang['maxlength'] = 'Longitud M&aacute;xima';
$lang['addfielddef'] = 'Agregar Definici&oacute;n de Campo';
$lang['customfields'] = 'Definici&oacute;n de Campos';
$lang['deprecated'] = 'sin soporte';
$lang['subject_newnews'] = 'Se ha ingresado un nuevo art&iacute;culo de Noticias';
$lang['email_subject'] = 'El Asunto del email saliente';
$lang['email_template'] = 'El formato del mensaje email';
$lang['formsubmit_emailaddress'] = 'Direcci&oacute;n email para recibir notificaciones de nuevos env&iacute;os';
$lang['extra'] = 'Extra ';
$lang['uploadscategory'] = 'Categor&iacute;a de Cargas';
$lang['title_available_templates'] = 'Plantillas Disponibles';
$lang['resettodefault'] = 'Resetear a Valores Iniciales';
$lang['title_form_template'] = 'Editor de Plantilla de Formulario';
$lang['title_detail_template'] = 'Editor de Plantilla de Detalles';
$lang['title_summary_template'] = 'Editor de Plantilla de Resumen';
$lang['prompt_templatename'] = 'Nombre de Plantilla';
$lang['prompt_template'] = 'Fuente de la Plantilla';
$lang['title_form_sysdefault'] = 'Formulario de Plantilla por Defecto';
$lang['title_summary_sysdefault'] = 'Plantilla de Resumen por Defecto';
$lang['title_detail_sysdefault'] = 'Plantilla de Detalles por Defecto';
$lang['info_sysdefault2'] = '<strong>Nota:</strong> Esta solapa contiene &aacute;reas de texto que van a permitir a usted editar a un grupo de plantillas que son mostradas cuando crea una \&#039;nueva\&#039; plantilla de resumen, detalles, o formulario.  Cambiando el contenido en &eacute;sta solapa, y haciendo click en \&#039;Enviar\&#039; <strong>no va a producir ning&uacute;n efecto en las actuales publicaciones</strong>.';
$lang['info_sysdefault'] = '<em>(el contenido usado por defecto cuando se crea una nueva plantilla)';
$lang['template'] = 'Plantilla';
$lang['prompt_name'] = 'Nombre';
$lang['prompt_default'] = 'Por Defecto';
$lang['prompt_newtemplate'] = 'Crear una Nueva Plantilla';
$lang['help_pagelimit'] = 'M&aacute;ximo n&uacute;mero de &iacute;tems a mostrar (por p&aacute;gina).  Si no se provee &eacute;ste par&aacute;metro se mostraran todos los items coincidentes.  Si est&aacute; fijado, y hay m&aacute;s items que los especificados por el par&aacute;metro, texto y enlaces ser&aacute;n provistos para poder desplazarse a trav&eacute;s de los resultados';
$lang['prompt_page'] = 'P&aacute;gina';
$lang['firstpage'] = '<< ';
$lang['prevpage'] = '< ';
$lang['nextpage'] = '> ';
$lang['lastpage'] = '>> ';
$lang['prompt_of'] = 'de';
$lang['prompt_pagelimit'] = 'L&iacute;mite de P&aacute;gina';
$lang['prompt_sorting'] = 'Ordenar por';
$lang['title_filter'] = 'Filtros';
$lang['published'] = 'Publicado';
$lang['draft'] = 'Borrador';
$lang['expired'] = 'Vencido';
$lang['author'] = 'Autor';
$lang['sysdefaults'] = 'Restaurar por defecto';
$lang['restoretodefaultsmsg'] = 'Esta operaci&oacute;n restaurar&aacute; el contenido de la plantilla al original por defecto. &iquest;Estas seguro de continuar?';
$lang['addarticle'] = 'A&ntilde;adir Art&iacute;culo';
$lang['articleadded'] = 'Se a&ntilde;adi&oacute; el art&iacute;culo correctamente.';
$lang['articleupdated'] = 'Se actualiz&oacute; el art&iacute;culo correctamente.';
$lang['articledeleted'] = 'Se borr&oacute; el art&iacute;culo correctamente.';
$lang['addcategory'] = 'A&ntilde;adir Categor&iacute;a';
$lang['categoryadded'] = 'Se a&ntilde;adi&oacute; la categor&iacute;a correctamente.';
$lang['categoryupdated'] = 'Se actualiz&oacute; la categor&iacute;a correctamente.';
$lang['categorydeleted'] = 'Se borr&oacute; la categor&iacute;a correctamente.';
$lang['addnewsitem'] = 'A&ntilde;adir Noticia';
$lang['allcategories'] = 'Todas las Categor&iacute;as';
$lang['allentries'] = 'Todas las Entradas';
$lang['areyousure'] = '&iquest;Seguro que quiere borrar?';
$lang['articles'] = 'Art&iacute;culos';
$lang['cancel'] = 'Cancelar';
$lang['category'] = 'Categor&iacute;a';
$lang['categories'] = 'Categor&iacute;as';
$lang['default_category'] = 'Categor&iacute;a por defecto';
$lang['content'] = 'Contenido';
$lang['dateformat'] = '%s no esta en formata yyyy-mm-dd hh:mm:ss v&aacute;lido';
$lang['delete'] = 'Borrar';
$lang['description'] = 'A&ntilde;adir, editar y borrar Noticias';
$lang['formtemplate'] = 'Plantillas de Formulario';
$lang['detailtemplate'] = 'Plantillas de Detalle';
$lang['default_templates'] = 'Plantillas por Defecto';
$lang['detailtemplateupdated'] = 'Se guard&oacute; correctamente en la base de datos la Plantilla de Detalle actualizada.';
$lang['displaytemplate'] = 'Mostrar Plantilla';
$lang['edit'] = 'Editar';
$lang['enddate'] = 'Fecha de Fin';
$lang['endrequiresstart'] = 'Una fecha de fin requiere tambi&eacute;n una fecha de inicio';
$lang['entries'] = '%s Entradas';
$lang['status'] = 'Estado';
$lang['expiry'] = 'Caducidad';
$lang['filter'] = 'Filtro';
$lang['more'] = 'M&aacute;s';
$lang['category_label'] = 'Categor&iacute;a:';
$lang['author_label'] = 'Enviado por:';
$lang['moretext'] = 'Texto M&aacute;s';
$lang['name'] = 'Nombre';
$lang['news'] = 'Noticias';
$lang['news_return'] = 'Volver';
$lang['newcategory'] = 'Nueva Categor&iacute;a';
$lang['needpermission'] = 'Necesitas permisos de &#039;%s&#039; para realizar esta funci&oacute;n.';
$lang['nocategorygiven'] = 'No hay Categor&iacute;a';
$lang['startdatetoolate'] = 'La Fecha de Comienzo es muy tarde (&iquest;posterior a fecha final?)';
$lang['nocontentgiven'] = 'No hay Contenido';
$lang['noitemsfound'] = '<strong>Ning&uacute;n</strong> elemento encontrado en categor&iacute;a: %s';
$lang['nopostdategiven'] = 'No hay Fecha de Envio';
$lang['note'] = '<em>Nota:</em> Las Fechas deben estar en formato &#039;yyyy-mm-dd hh:mm:ss&#039;.';
$lang['notitlegiven'] = 'No hay T&iacute;tulo';
$lang['nonamegiven'] = 'No hay Nombre';
$lang['numbertodisplay'] = 'N&uacute;mero a Mostrar (en blanco, muestra todos)';
$lang['print'] = 'Imprimir';
$lang['postdate'] = 'Fecha de Env&iacute;o';
$lang['postinstall'] = 'Ten por seguro activar permisos para &quot;Modifcar Noticia&quot; en los usuarios que administren noticias.';
$lang['selectcategory'] = 'Seleccionar Categor&iacute;a';
$lang['showchildcategories'] = 'Mostrar Subcategor&iacute;as';
$lang['sortascending'] = 'Orden Ascendente';
$lang['startdate'] = 'Fecha de Inicio';
$lang['startoffset'] = 'Comienza a mostrar desde el elemento';
$lang['startrequiresend'] = 'Una fecha de inicio requiere tambi&eacute;n una de fin';
$lang['submit'] = 'Enviar';
$lang['summary'] = 'Sumario';
$lang['summarytemplate'] = 'Plantilla de Sumario';
$lang['summarytemplateupdated'] = 'Plantilla de Sumario de Noticias actualizada correctamente.';
$lang['title'] = 'T&iacute;tulo';
$lang['options'] = 'Opciones';
$lang['optionsupdated'] = 'Opciones actualizadas correctamente.';
$lang['useexpiration'] = 'Usar Fecha de Caducidad';
$lang['eventdesc-NewsArticleAdded'] = 'Se envia cuando a&ntilde;adimos un art&iacute;culo.';
$lang['eventhelp-NewsArticleAdded'] = '<p>Se env&iacute;a cuando a&ntilde;adimos un art&iacute;culo.</p>
<h4>Par&aacute;metros</h4>
<ul>
<li>\&quot;news_id\&quot; - Id del art&iacute;culo</li>
<li>\&quot;category_id\&quot; - Id de la categor&iacute;a del art&iacute;culo</li>
<li>\&quot;title\&quot; - T&iacute;tulo del art&iacute;culo</li>
<li>\&quot;content\&quot; - Contenido del art&iacute;culo</li>
<li>\&quot;summary\&quot; - Sumario del art&iacute;culo</li>
<li>\&quot;status\&quot; - estado del art&iacute;culo (&quot;borrador&quot; o &quot;publicado&quot;)</li>
<li>\&quot;start_time\&quot; - Fecha de inicio de publicaci&oacute;n del art&iacute;culo</li>
<li>\&quot;end_time\&quot; - Fecha de caducidad del art&iacute;culo</li>
<li>\&quot;useexp\&quot; - Define si la fecha de vencimiento se ignora o no</li>
</ul>
';
$lang['eventdesc-NewsArticleEdited'] = 'Se envia cuando editamos un art&iacute;culo.';
$lang['eventhelp-NewsArticleEdited'] = '<p>Se env&iacute;a cuando editamos un art&iacute;culo.</p>
<h4>Par&aacute;metros</h4>
<ul>
<li>\&quot;news_id\&quot; - Id del art&iacute;culo</li>
<li>\&quot;category_id\&quot; - Id de la categor&iacute;a del art&iacute;culo</li>
<li>\&quot;title\&quot; - T&iacute;tulo del art&iacute;culo</li>
<li>\&quot;content\&quot; - Contenido del art&iacute;culo</li>
<li>\&quot;summary\&quot; - Sumario del art&iacute;culo</li>
<li>\&quot;status\&quot; - estado del art&iacute;culo (&quot;borrador&quot; o &quot;publicado&quot;)</li>
<li>\&quot;start_time\&quot; - Fecha de inicio de publicaci&oacute;n del art&iacute;culo</li>
<li>\&quot;end_time\&quot; - Fecha de caducidad del art&iacute;culo</li>
<li>\&quot;useexp\&quot; - Define si la fecha de vencimiento se ignora o no</li>
</ul>
';
$lang['eventdesc-NewsArticleDeleted'] = 'Se env&iacute;a cuando eliminamos un art&iacute;culo.';
$lang['eventhelp-NewsArticleDeleted'] = '<p>Se env&iacute;a cuando eliminamos un art&iacute;culo.</p>
<h4>Par&aacute;metros</h4>
<ul>
<li>\&quot;news_id\&quot; - Id del art&iacute;culo de noticias</li>
</ul>';
$lang['eventdesc-NewsCategoryAdded'] = 'Se env&iacute;a cuando a&ntilde;adimos una categor&iacute;a.';
$lang['eventhelp-NewsCategoryAdded'] = '<p>Se env&iacute;a cuando a&ntilde;adimos una categor&iacute;a.</p>
<h4>Par&aacute;metros</h4>
<ul>
<li>\&quot;category_id\&quot; - Id de la categor&iacute;a del art&iacute;culo</li>
<li>\&quot;name\&quot; - Nombre de la categor&iacute;a</li>
</ul>';
$lang['eventdesc-NewsCategoryEdited'] = 'Se envia cuando editamos una categor&iacute;a.';
$lang['eventhelp-NewsCategoryEdited'] = '<p>Se env&iacute;a cuando editamos una categor&iacute;a.</p>
<h4>Par&aacute;metros</h4>
<ul>
<li>\&quot;category_id\&quot; - Id de la categor&iacute;a de noticias</li>
<li>\&quot;name\&quot; - Nombre de la categor&iacute;a de noticias</li>
<li>\&quot;origname\&quot; - El nombre original de la categor&iacute;a de noticias</li>
</ul>';
$lang['eventdesc-NewsCategoryDeleted'] = 'Se env&iacute;a cuando eliminamos una categor&iacute;a.';
$lang['eventhelp-NewsCategoryDeleted'] = '<p>Se env&iacute;a cuando eliminamos una categor&iacute;a.</p>
<h4>Par&aacute;metros</h4>
<ul>
<li>\&quot;category_id\&quot; - Id de la categor&iacute;a eliminada</li>
<li>\&quot;name\&quot; - Nombre de la categor&iacute;a eliminada</li>
</ul>
';
$lang['help_articleid'] = 'Este parametro no aplica en la vista detallada. Permite especificar cuales de los articulos se despliegan en la vista detallada. Si el valor especial -1 es utilizado, el sistema desplegar&aacute; el articulo mas nuevo, publicado, que no ha expirado.';
$lang['helpnumber'] = 'N&uacute;mero m&aacute;ximo de elementos a mostrar =- dej&aacute;ndolo blanco muestra todos.';
$lang['helpstart'] = 'Comenzar por el n-esimo item -- dej&aacute;ndolo blanco comenzar&aacute; por el primero.';
$lang['helpcategory'] = 'S&oacute;lo mostrar elementos de esa categor&iacute;a. <b>Usar * despu&eacute;s del nombre para mostrar sub-categor&iacute;as.</b>  Se puede usar m&uacute;ltiples categor&iacute;as, separadas por una coma, dej&aacute;ndolo blanco muestra todas las categor&iacute;as.';
$lang['helpmoretext'] = 'Texto a mostrar al final de un item noticia si esta supera la longitud del sumario.  Por defecto es &quot;M&aacute;s...&quot;';
$lang['helpsummarytemplate'] = 'Usar una plantilla distinta en la base de datos para mostrar el resumen del art&iacute;culo.  Esta plantilla debe existir y estar visible en la solapa de la plantilla de resumen de la administraci&oacute;n de Noticias, sin embargo no tiene porqu&eacute; ser la plantilla por defecto.  Si este par&aacute;metro no se especifica, entonces se usar&aacute; a la actual plantilla marcada como por defecto.';
$lang['helpformtemplate'] = 'Usar una plantilla de la base de datos para mostrar el formulario de presentaci&oacute;n del art&iacute;culo. Esta plantilla debe existir y estar visible en la solapa de formularios de plantillas de la administraci&oacute;n de Noticias, sin embargo no tiene porqu&eacute; ser la plantilla por defecto.  Si este par&aacute;metro no se especifica, entonces se usar&aacute; a la actual plantilla marcada como por defecto.';
$lang['helpbrowsecattemplate'] = 'Usar una plantilla de la base de datos para mostrar el explorador de categor&iacute;as.  Esta plantilla debe existir y estar visible en la solapa de Plantillas de Exploraci&oacute;n de Categor&iacute;as de la administraci&oacute;n de Noticias, sin embargo no tiene porqu&eacute; ser la plantilla por defecto.  Si este par&aacute;metro no se especifica, entonces se usar&aacute; a la actual plantilla marcada como por defecto.';
$lang['helpdetailtemplate'] = 'Usar una plantilla distinta en la base de datos para mostrar el detalle del art&iacute;culo. Esta plantilla debe existir y estar visible en la solapa de plantilla de detalles de la administraci&oacute;n de Noticias, sin embargo no tiene porqu&eacute; ser la plantilla por defecto.  Si este par&aacute;metro no se especifica, entonces se usar&aacute; a la actual plantilla marcada como por defecto.';
$lang['helpsortby'] = 'Campo por el que ordenar.  Las opciones son: &quot;news_date&quot;, &quot;summary&quot;, &quot;news_data&quot;, &quot;news_category&quot;, &quot;news_title&quot;, &quot;random&quot;.  Por  defecto est&aacute; puesto &quot;news_date&quot;. Si se especifica &quot;random&quot;, el par&aacute;metro sortasc es ignorado.';
$lang['helpsortasc'] = 'Ordenar noticias por fechas en orden ascendente en lugar de descendente.';
$lang['helpdetailpage'] = 'P&aacute;gina para las Noticias.  Puede ser un alias o un id de p&aacute;gina. Se usa para mostrar las noticias con una plantilla distinta a la del sumario.';
$lang['helpshowarchive'] = 'Mostrar solo art&iacute;culos de noticias caducas.';
$lang['helpbrowsecat'] = 'Muestra un listado de categor&iacute;as que se puede examinar.';
$lang['helpaction'] = 'Hace a un lado la acci&oacute;n por defecto.  Los valores posibles son &#039;default&#039; para mostrar la vista resumen, y &#039;fesubmit&#039; para mostrar el formulario en el portal para permitir a los usuarios enviar art&iacute;culos desde all&iacute;.';
$lang['help'] = '<h3>Notas Importantes</h3>
<p>Esta versi&oacute;n de Noticias es mayor a la suministrada con la versi&oacute;n 1.1 de CMS Made Simple.  Si usted utiliza esta versi&oacute;n de Noticias debe tener cuidado extremo cuando hace una actualizaci&oacute;n de CMS Made Simple para asegurarse de que nada en el directorio de modules/News sea sobre escrito.</p>
	<h3>&iquest;Qu&eacute; hace esto?</h3>
	<p>Noticias es un m&oacute;dulo para mostrar noticias de acontecimientos en su p&aacute;gina, similar al estilo de un blog, pero &iexcl;con m&aacute;s posibilidades!.  Cuando el m&oacute;dulo est&aacute; instalado, se agrega una p&aacute;gina de Administraci&oacute;n de Noticias al men&uacute; de Administraci&oacute;n que le permitir&aacute;n seleccionar o agregar nuevas categor&iacute;as.  Una vez que una nueva categor&iacute;a es seleccionada o creada, una lista de nuevos items para esa categor&iacute;a se mostrar&aacute;n.  Desde aqu&iacute; en m&aacute;s, usted puede agregar, editar o eliminar items para esa categor&iacute;a.</p>
	<h3>Variables de plantillas</h3>
	<ul>
		<li><b>itemcount</b> - El n&uacute;mero de nuevos art&iacute;culos a mostrar.</li>
		<li><b>entry->authorname</b> - El nombre completo del autor, incluyendo Nombre y Apellido.</li>
	</ul>
	<h3>Seguridad</h3>
	<p>El usuario debe pertenecer a un grupo que tenga el permiso &#039;Modificar Noticias&#039; con el fin de agregar, editar, o eliminar entradas de Noticias.</p>
	<p>Con el fin de editar los layouts de las plantillas, el usuario debe pertenecer a un grupo con el permiso de &#039;Modificar Plantillas&#039;.</p>
	<p>Con el fin de editar las preferencias globales de noticias, el usuario debe pertenecer a un grupo que tenga permiso para &#039;Modificar las Preferencias del Sitio&#039;.</p>
	<p>Adem&aacute;s, para aprobar noticias que ser&aacute;n vistas en el portal, el usuario deber&aacute; pertenecer a un grupo con el permiso para &#039;Aprobar Noticias&#039;.</p>
	<h3>&iquest;Como uso a &eacute;ste m&oacute;dulo?</h3>
	<p>La forma m&aacute;s sencilla de utilizarlo es con el tag de envoltura {news} (esto hace funcionar al m&oacute;dulo dentro de un tag, para simplificar la sintaxis).  De esta forma el m&oacute;dulo ser&aacute; insertado y funcionar&aacute; en su plantilla o p&aacute;gina en cualquier lugar que usted lo desee, desplegando los items de noticias.  El c&oacute;digo ingresado se ver&aacute; aproximadamente as&iacute;: <code>{news number=&#039;5&#039;}</code></p>
<h3>Plantillas</h3>
	<p>Desde la versi&oacute;n 2.3 News soporta m&uacute;ltiples plantillas de base de datos, y ya no soporta m&aacute;s archivos adicionales de plantillas.  Los usuarios que ya han usado el viejo sistema de plantillas con archivos deber&aacute;n seguir estos pasos (para cada plantilla):
<ul>
<li>Copiar el archivo de plantilla en el sujetapapeles (clipboard)</li>
<li>Crear una nueva plantilla en la base de datos <em>(puede ser de resumen o de detalles como es requerido)</em>.  De a la nueva plantilla el mismo nombre (incluyendo la extensi&oacute;n .tpl) como ten&iacute;a la vieja plantilla de archivo, pegar el contenido que tenemos guardado en el sujetapapeles.</li>
<li>Hacer Click en Enviar</li>
</ul>
Al seguir estos pasos se deber&iacute;an solucionar todos aquellos problemas de plantillas de noticias que no son encontradas y otros errores de smarty similares que aparecen cuando usted actualiza su versi&oacute;n de CMS MS a una que tiene el m&oacute;dulo News 2.3 o mayor.</p>';
$lang['utma'] = '156861353.661434885.1227567621.1241502996.1241545688.65';
$lang['utmz'] = '156861353.1241473702.63.28.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php/board,30.0.html|utmcmd=referral';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353';
?>